==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/jgo-CM.pl <==
{
  am_pm_abbreviated => [
    "mba\N{U+a78c}mba\N{U+a78c}",
    "\N{U+014b}ka mb\N{U+0254}\N{U+0301}t nji"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "d.M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "M.d.y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "jgo-CM",
  date_format_full => "EEEE, y MMMM dd",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi"
  ],
  day_format_narrow => [
    "M\N{U+0254}\N{U+0301}",
    "\N{U+00c1}M",
    "W\N{U+025b}\N{U+0301}",
    "T\N{U+0254}\N{U+0301}",
    "F\N{U+025b}",
    "S\N{U+00e1}",
    "S\N{U+0254}\N{U+0301}"
  ],
  day_format_wide => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi"
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi"
  ],
  day_stand_alone_narrow => [
    "M\N{U+0254}\N{U+0301}",
    "\N{U+00c1}M",
    "W\N{U+025b}\N{U+0301}",
    "T\N{U+0254}\N{U+0301}",
    "F\N{U+025b}",
    "S\N{U+00e1}",
    "S\N{U+0254}\N{U+0301}"
  ],
  day_stand_alone_wide => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi"
  ],
  era_abbreviated => [
    "BCE",
    "CE"
  ],
  era_narrow => [
    "BCE",
    "CE"
  ],
  era_wide => [
    "ts\N{U+025b}tts\N{U+025b}t m\N{U+025b}\N{U+014b}gu\N{U+a78c} mi \N{U+025b}\N{U+0301} l\N{U+025b}\N{U+025b}n\N{U+025b} K\N{U+025b}l\N{U+00ed}s\N{U+025b}t\N{U+0254} g\N{U+0254} \N{U+0144}\N{U+0254}\N{U+0301}",
    "ts\N{U+025b}tts\N{U+025b}t m\N{U+025b}\N{U+014b}gu\N{U+a78c} mi \N{U+025b}\N{U+0301} f\N{U+00fa}n\N{U+025b} K\N{U+025b}l\N{U+00ed}s\N{U+025b}t\N{U+0254} t\N{U+0254}\N{U+0301} m\N{U+0254}\N{U+0301}"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ngomba",
  month_format_abbreviated => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}"
  ],
  month_stand_alone_abbreviated => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}"
  ],
  name => "Ngomba Cameroon",
  native_language => "Nda\N{U+a78c}a",
  native_name => "Nda\N{U+a78c}a Kam\N{U+025b}l\N{U+00fb}n",
  native_script => undef,
  native_territory => "Kam\N{U+025b}l\N{U+00fb}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.23.tar.gz: DateTime-Locale-1.23/share/jgo-CM.pl <==
{
  am_pm_abbreviated => [
    "mba\N{U+a78c}mba\N{U+a78c}",
    "\N{U+014b}ka mb\N{U+0254}\N{U+0301}t nji",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "d.M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "M.d.y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "jgo-CM",
  date_format_full => "EEEE, y MMMM dd",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi",
  ],
  day_format_narrow => [
    "M\N{U+0254}\N{U+0301}",
    "\N{U+00c1}M",
    "W\N{U+025b}\N{U+0301}",
    "T\N{U+0254}\N{U+0301}",
    "F\N{U+025b}",
    "S\N{U+00e1}",
    "S\N{U+0254}\N{U+0301}",
  ],
  day_format_wide => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi",
  ],
  day_stand_alone_narrow => [
    "M\N{U+0254}\N{U+0301}",
    "\N{U+00c1}M",
    "W\N{U+025b}\N{U+0301}",
    "T\N{U+0254}\N{U+0301}",
    "F\N{U+025b}",
    "S\N{U+00e1}",
    "S\N{U+0254}\N{U+0301}",
  ],
  day_stand_alone_wide => [
    "M\N{U+0254}\N{U+0301}ndi",
    "\N{U+00c1}pta M\N{U+0254}\N{U+0301}ndi",
    "W\N{U+025b}\N{U+0301}n\N{U+025b}s\N{U+025b}d\N{U+025b}",
    "T\N{U+0254}\N{U+0301}s\N{U+025b}d\N{U+025b}",
    "F\N{U+025b}l\N{U+00e2}y\N{U+025b}d\N{U+025b}",
    "S\N{U+00e1}sid\N{U+025b}",
    "S\N{U+0254}\N{U+0301}ndi",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "ts\N{U+025b}tts\N{U+025b}t m\N{U+025b}\N{U+014b}gu\N{U+a78c} mi \N{U+025b}\N{U+0301} l\N{U+025b}\N{U+025b}n\N{U+025b} K\N{U+025b}l\N{U+00ed}s\N{U+025b}t\N{U+0254} g\N{U+0254} \N{U+0144}\N{U+0254}\N{U+0301}",
    "ts\N{U+025b}tts\N{U+025b}t m\N{U+025b}\N{U+014b}gu\N{U+a78c} mi \N{U+025b}\N{U+0301} f\N{U+00fa}n\N{U+025b} K\N{U+025b}l\N{U+00ed}s\N{U+025b}t\N{U+0254} t\N{U+0254}\N{U+0301} m\N{U+0254}\N{U+0301}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ngomba",
  month_format_abbreviated => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}",
  ],
  month_stand_alone_abbreviated => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Ndu\N{U+014b}mbi Sa\N{U+014b}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}p\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}t\N{U+00e1}t",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}kwa",
    "P\N{U+025b}sa\N{U+014b} Pataa",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}nt\N{U+00fa}k\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} Saamb\N{U+00e1}",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}f\N{U+0254}m",
    "P\N{U+025b}sa\N{U+014b} P\N{U+025b}\N{U+0301}n\N{U+025b}\N{U+0301}pf\N{U+00fa}\N{U+a78b}\N{U+00fa}",
    "P\N{U+025b}sa\N{U+014b} N\N{U+025b}g\N{U+025b}\N{U+0301}m",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pm\N{U+0254}\N{U+0301}",
    "P\N{U+025b}sa\N{U+014b} Nts\N{U+0254}\N{U+030c}pp\N{U+00e1}",
  ],
  name => "Ngomba Cameroon",
  native_language => "Nda\N{U+a78c}a",
  native_name => "Nda\N{U+a78c}a Kam\N{U+025b}l\N{U+00fb}n",
  native_script => undef,
  native_territory => "Kam\N{U+025b}l\N{U+00fb}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 34,
}
